//   Copyright 2012 Georg-August-Universität Göttingen, Germany
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

package de.ugoe.cs.autoquest.tasktrees.taskequality;

import static org.junit.Assert.*;

import org.junit.Test;

import de.ugoe.cs.autoquest.eventcore.IEventTarget;
import de.ugoe.cs.autoquest.eventcore.IEventType;
import de.ugoe.cs.autoquest.eventcore.StringEventType;
import de.ugoe.cs.autoquest.tasktrees.taskequality.TaskAndSelectionComparisonRule;
import de.ugoe.cs.autoquest.tasktrees.taskequality.TaskEquality;
import de.ugoe.cs.autoquest.tasktrees.taskequality.TaskEqualityRuleManager;
import de.ugoe.cs.autoquest.tasktrees.treeifc.ISelection;
import de.ugoe.cs.autoquest.tasktrees.treeifc.ITaskBuilder;
import de.ugoe.cs.autoquest.tasktrees.treeifc.ITask;
import de.ugoe.cs.autoquest.tasktrees.treeifc.ITaskFactory;
import de.ugoe.cs.autoquest.tasktrees.treeimpl.TaskBuilder;
import de.ugoe.cs.autoquest.tasktrees.treeimpl.TaskFactory;
import de.ugoe.cs.autoquest.test.DummyGUIElement;

/**
 * @author Patrick Harms
 */
public class TaskAndSelectionComparisonRuleTest {

    /**
     *
     */
    @Test
    public void test() {
        TaskEqualityRuleManager manager = new TaskEqualityRuleManager();
        manager.init();
        
        ITaskFactory taskFactory = new TaskFactory();
        ITaskBuilder treeBuilder = new TaskBuilder();
        
        TaskAndSelectionComparisonRule rule = new TaskAndSelectionComparisonRule(manager);
        
        IEventType eventType1 = new StringEventType("eventType1");
        IEventTarget eventTarget1 = new DummyGUIElement("elem1");
        ITask task1 = taskFactory.createNewEventTask(eventType1, eventTarget1);
        
        assertNull(rule.compare(task1, task1));
        
        ISelection selection1 = taskFactory.createNewSelection();
        assertNull(rule.compare(selection1, selection1));
        assertNull(rule.compare(task1, selection1));
        assertNull(rule.compare(selection1, task1));

        treeBuilder.addChild(selection1, task1);
        
        assertEquals(TaskEquality.LEXICALLY_EQUAL, rule.compare(selection1, task1));
        assertEquals(TaskEquality.LEXICALLY_EQUAL, rule.compare(task1, selection1));
        
        selection1 = taskFactory.createNewSelection();
        ISelection selection2 = taskFactory.createNewSelection();
        treeBuilder.addChild(selection2, task1);
        treeBuilder.addChild(selection1, selection2);
        
        assertEquals(TaskEquality.LEXICALLY_EQUAL, rule.compare(selection1, task1));
        assertEquals(TaskEquality.LEXICALLY_EQUAL, rule.compare(task1, selection1));
    }

}
